@@ -17,17 +17,20 @@
 """
 *New in pywbem 0.9 as experimental and finalized in 0.10.*
 
-The WBEM server API encapsulates certain functionality of a WBEM server for use
-by a WBEM client application, such as determining the Interop namespace of the
-server, or the management profiles advertised by the server.
+The WBEM server library API of pywbem encapsulates selected functionality of a
+WBEM server for use by a WBEM client application, such as determining the
+Interop namespace and other basic information about the server, or the
+management profiles advertised by the server.
 
 This chapter has the following sections:
 
-* :ref:`Example <Server Example>` - An example on how to use the API.
+* :ref:`Example <Server Example>` - An example on how to use the WBEM server
+  library API.
 
 * :ref:`WBEMServer` - The :class:`~pywbem.WBEMServer` class serves as a general
   access point for clients to WBEM servers. It allows determining the Interop
-  namespace of the server, or the advertised management profiles.
+  namespace of the server and other basic information about the server, or the
+  advertised management profiles.
 
 .. _`Server Example`:
 
@@ -238,11 +241,7 @@ class WBEMServer(object):
         Raises:
 
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
-            ModelError: An issue with the model implemented by the WBEM server.
-            CIMError: CIM_ERR_NOT_FOUND, Interop namespace could not be
-              determined.
-            CIMError: CIM_ERR_NOT_FOUND, Namespace class could not be
-              determined.
+            ModelError: An error with the model implemented by the WBEM server.
         """
         if self._namespace_classname is None:
             self._determine_namespaces()
@@ -257,11 +256,7 @@ class WBEMServer(object):
         Raises:
 
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
-            ModelError: An issue with the model implemented by the WBEM server.
-            CIMError: CIM_ERR_NOT_FOUND, Interop namespace could not be
-              determined.
-            CIMError: CIM_ERR_NOT_FOUND, Namespace class could not be
-              determined.
+            ModelError: An error with the model implemented by the WBEM server.
         """
         if self._namespaces is None:
             self._determine_namespaces()
@@ -283,11 +278,7 @@ class WBEMServer(object):
         Raises:
 
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
-            ModelError: An issue with the model implemented by the WBEM server.
-            CIMError: CIM_ERR_NOT_FOUND, Interop namespace could not be
-              determined.
-            CIMError: CIM_ERR_NOT_FOUND, Namespace class could not be
-              determined.
+            ModelError: An error with the model implemented by the WBEM server.
         """
         if self._namespace_paths is None:
             self._determine_namespaces()
@@ -427,15 +418,7 @@ class WBEMServer(object):
         Raises:
 
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
-            ModelError: An issue with the model implemented by the WBEM server.
-            CIMError: CIM_ERR_ALREADY_EXISTS, Specified namespace already
-              exists in the WBEM server.
-            CIMError: CIM_ERR_NOT_FOUND, Interop namespace could not be
-              determined.
-            CIMError: CIM_ERR_NOT_FOUND, Unexpected number of
-              `CIM_ObjectManager` instances.
-            CIMError: CIM_ERR_FAILED, Unexpected number of
-              central instances of WBEM Server profile.
+            ModelError: An error with the model implemented by the WBEM server.
         """
 
         std_namespace = _ensure_unicode(namespace.strip('/'))
@@ -450,8 +433,7 @@ class WBEMServer(object):
             ws_profile_inst = ws_profiles_sorted[-1]  # latest version
             ws_insts = self.get_central_instances(ws_profile_inst.path)
             if len(ws_insts) != 1:
-                raise CIMError(
-                    CIM_ERR_FAILED,
+                raise ModelError(
                     _format("Unexpected number of central instances of WBEM "
                             "Server profile: {0!A}",
                             [i.path for i in ws_insts]))
@@ -477,8 +459,7 @@ class WBEMServer(object):
                     raise
             else:
                 if ret_val != 0:
-                    raise CIMError(
-                        CIM_ERR_FAILED,
+                    raise ModelError(
                         _format("The CreateWBEMServerNamespace() method is "
                                 "implemented but failed: {0}",
                                 out_params['Errors']))
@@ -573,11 +554,10 @@ class WBEMServer(object):
         Raises:
 
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
-            ModelError: An issue with the model implemented by the WBEM server.
+            ModelError: An error with the model implemented by the WBEM server.
             CIMError: CIM_ERR_NOT_FOUND, Specified namespace does not exist.
             CIMError: CIM_ERR_NAMESPACE_NOT_EMPTY, Specified namespace is not
               empty.
-            Additional CIM errors.
         """
 
         std_namespace = _ensure_unicode(namespace.strip('/'))
@@ -591,7 +571,8 @@ class WBEMServer(object):
         if std_namespace not in self.namespaces:
             raise CIMError(
                 CIM_ERR_NOT_FOUND,
-                _format("Specified namespace does not exist: {0!A}",
+                _format("pywbem detected that the specified namespace does not "
+                        "exist: {0!A}",
                         std_namespace),
                 conn_id=self.conn.conn_id)
 
@@ -612,7 +593,8 @@ class WBEMServer(object):
         if class_paths or quals:
             raise CIMError(
                 CIM_ERR_NAMESPACE_NOT_EMPTY,
-                _format("Specified namespace {0!A} is not empty; it contains "
+                _format("pywbem detected that the specified namespace {0!A} "
+                        "is not empty; it contains "
                         "{1} top-level classes and {2} qualifier types",
                         std_namespace, len(class_paths), len(quals)),
                 conn_id=self.conn.conn_id)
@@ -857,13 +839,13 @@ class WBEMServer(object):
         Raises:
 
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
-            ModelError: Model implementation errors on the server.
+            ModelError: An error with the model implemented by the WBEM server.
             ValueError: User errors regarding input parameter values.
             TypeError: User errors regarding input parameter types.
         """
 
         if reference_direction not in ('dmtf', 'snia'):
-            ValueError(
+            raise ValueError(
                 _format("The reference_direction parameter must be 'dmtf' or "
                         "'snia', but is: {0!A}", reference_direction))
 
@@ -1074,8 +1056,7 @@ class WBEMServer(object):
         Raises:
 
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
-            CIMError: CIM_ERR_NOT_FOUND, Interop namespace could not be
-              determined.
+            ModelError: An error with the model implemented by the WBEM server.
         """
         test_classname = 'CIM_Namespace'
         interop_ns = None
@@ -1087,14 +1068,13 @@ class WBEMServer(object):
                 if exc.status_code == CIM_ERR_INVALID_NAMESPACE:
                     # Current namespace does not exist.
                     continue
-                elif exc.status_code in (CIM_ERR_INVALID_CLASS,
-                                         CIM_ERR_NOT_FOUND):
+                if exc.status_code in (CIM_ERR_INVALID_CLASS,
+                                       CIM_ERR_NOT_FOUND):
                     # Class is not implemented, but current namespace exists.
                     interop_ns = ns
                     break
-                else:
-                    # Some other error happened.
-                    raise
+                # Some other error happened.
+                raise
             else:
                 # Namespace class is implemented in the current namespace.
                 # Use the returned namespace name, if possible.
@@ -1107,8 +1087,7 @@ class WBEMServer(object):
                 break
         if interop_ns is None:
             # Exhausted the possible namespaces
-            raise CIMError(
-                CIM_ERR_NOT_FOUND,
+            raise ModelError(
                 _format("Interop namespace could not be determined "
                         "(tried {0!A})", self.INTEROP_NAMESPACES),
                 conn_id=self.conn.conn_id)
@@ -1172,11 +1151,7 @@ class WBEMServer(object):
         Raises:
 
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
-            ModelError: An issue with the model implemented by the WBEM server.
-            CIMError: CIM_ERR_NOT_FOUND, Interop namespace could not be
-              determined.
-            CIMError: CIM_ERR_NOT_FOUND, Namespace class could not be
-              determined.
+            ModelError: An error with the model implemented by the WBEM server.
         """
         ns_insts = None
         ns_classname = None
@@ -1190,17 +1165,15 @@ class WBEMServer(object):
                                        CIM_ERR_NOT_FOUND):
                     # Class is not implemented, try next one.
                     continue
-                else:
-                    # Some other error.
-                    raise
+                # Some other error.
+                raise
             else:
                 # Found a namespace class that is implemented.
                 ns_classname = classname
                 break
         if ns_insts is None:
             # Exhausted the possible class names
-            raise CIMError(
-                CIM_ERR_NOT_FOUND,
+            raise ModelError(
                 _format("Namespace class could not be determined "
                         "(tried {0!A})", self.NAMESPACE_CLASSNAMES),
                 conn_id=self.conn.conn_id)
@@ -1233,16 +1206,12 @@ class WBEMServer(object):
         Raises:
 
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
-            CIMError: CIM_ERR_NOT_FOUND, Interop namespace could not be
-              determined.
-            CIMError: CIM_ERR_NOT_FOUND, Unexpected number of
-              `CIM_ObjectManager` instances.
+            ModelError: An error with the model implemented by the WBEM server.
         """
         cimom_insts = self._conn.EnumerateInstances(
             "CIM_ObjectManager", namespace=self.interop_ns)
         if len(cimom_insts) != 1:
-            raise CIMError(
-                CIM_ERR_NOT_FOUND,
+            raise ModelError(
                 _format("Unexpected number of CIM_ObjectManager instances: "
                         "{0!A} ", [i['ElementName'] for i in cimom_insts]),
                 conn_id=self.conn.conn_id)
@@ -1312,8 +1281,7 @@ class WBEMServer(object):
         Raises:
 
             Exceptions raised by :class:`~pywbem.WBEMConnection`.
-            CIMError: CIM_ERR_NOT_FOUND, Interop namespace could not be
-              determined.
+            ModelError: An error with the model implemented by the WBEM server.
         """
         mp_insts = self._conn.EnumerateInstances("CIM_RegisteredProfile",
                                                  namespace=self.interop_ns)
