@@ -74,22 +74,9 @@ class ResolverMixin(object):  # pylint: disable=too-few-public-methods
        attributes such as class_origin, and propagated properties.
 
     """
-    @staticmethod
-    def _test_qualifier_decl(qualifier, qualifier_store, namespace):
-        """
-        Test that qualifier is in repo and valid.
-        """
-        if qualifier_store is None:
-            return
-        if not qualifier_store.object_exists(qualifier.name):
-            raise CIMError(
-                CIM_ERR_INVALID_PARAMETER,
-                _format("Qualifier declaration {0!A} required by CreateClass "
-                        "not found in namespace {1!A}.",
-                        qualifier.name, namespace))
 
     @staticmethod
-    def _validate_qualifiers(qualifier_list, qualifier_store, new_class, scope):
+    def _validate_qualifiers(qualifiers, qualifier_store, new_class, scope):
         """
         Validate a list of qualifiers against the Qualifier decl in the
         repository.
@@ -99,8 +86,23 @@ class ResolverMixin(object):  # pylint: disable=too-few-public-methods
         3. Whether the qualifier is valid for the given scope.
         4. Whether the qualifier can be overridden.
         5. Whether the qualifier should be propagated to the subclass.
+
+        Parameters:
+
+          qualifiers: (:class:`py:dict` or `NocaseDict`_):
+             Qualifiers to validate
+
+          qualifier_store ():
+
+          new_class (:class:`~pywbem.CIMClass`):
+            The class being validated
+
+        scope (:term:`string`):
+            The scope defined for the object containing the qualifiers.
+            May be 'CLASS', 'PROPERTY', 'METHOD', 'PARAMETER'
+
         """
-        for qname, qual in qualifier_list.items():
+        for qname, qual in qualifiers.items():
             if not qualifier_store.object_exists(qname):
                 raise CIMError(
                     CIM_ERR_INVALID_PARAMETER,
@@ -116,13 +118,17 @@ class ResolverMixin(object):  # pylint: disable=too-few-public-methods
                             "{3!A}).",
                             qname, new_class.classname, qual.type,
                             q_decl.type))
-            if scope not in q_decl.scopes and 'ANY' not in q_decl.scopes:
+
+            # Test for valid scope for this object type ot qualdecl ANY
+            if not q_decl.scopes[scope] and not q_decl.scopes['ANY']:
                 raise CIMError(
                     CIM_ERR_INVALID_PARAMETER,
                     _format("Qualifier {0!A} in new class {1!A} is used in "
-                            "invalid scope {2!A} (Qualifier declaration "
-                            "scopes: {3})",
-                            qname, new_class.classname, scope, q_decl.scopes))
+                            "invalid scope: {2!A}. (QualifierDeclaration "
+                            "scopes: ({3})",
+                            qname, new_class.classname, scope,
+                            ", ".join(
+                                [s for s, v in q_decl.scopes.items() if v])))
 
     @staticmethod
     def _init_qualifier(qualifier, qualifier_store):
@@ -145,20 +151,6 @@ class ResolverMixin(object):  # pylint: disable=too-few-public-methods
         if qualifier.translatable is None:
             qualifier.translatable = qual_dict_entry.translatable
 
-    @staticmethod
-    def _init_qualifier_decl(qualifier_decl, qualifier_store):
-        """
-        Initialize the flavors of a qualifier declaration if they are not
-        already set.
-        """
-        assert qualifier_store.object_exists(qualifier_decl.name)
-        if qualifier_decl.tosubclass is None:
-            qualifier_decl.tosubclass = True
-        if qualifier_decl.overridable is None:
-            qualifier_decl.overridable = True
-        if qualifier_decl.translatable is None:
-            qualifier_decl.translatable = False
-
     def _resolve_objects(self, new_objects, superclass_objects, new_class,
                          superclass, classrepo, qualifier_store, type_str,
                          verbose=None):
@@ -184,7 +176,8 @@ class ResolverMixin(object):  # pylint: disable=too-few-public-methods
                                      False, type_str)
                 continue
 
-            # If obj_name in superclass_objects
+            # Error if obj_name in superclass_objects and not override,
+            # except parameters which have no override concept.
             if 'Override' not in new_objects[obj_name].qualifiers:
                 if not isinstance(new_objects[obj_name], CIMParameter):
                     raise CIMError(
@@ -193,8 +186,6 @@ class ResolverMixin(object):  # pylint: disable=too-few-public-methods
                                 "{3!A} without override.",
                                 type_str, obj_name, new_class.classname,
                                 superclass.classname))
-
-                # TODO need to finish this.  For now let parameter slide
                 continue
 
             # process object override
@@ -428,7 +419,7 @@ class ResolverMixin(object):  # pylint: disable=too-few-public-methods
                 raise CIMError(
                     CIM_ERR_INVALID_PARAMETER,
                     _format("New class {0!A} derived from superclass {1!A} "
-                            "in namespace {3!A} which is not Association "
+                            "in namespace {2!A} which is not Association "
                             "Class .",
                             new_class.classname, new_class.superclass,
                             namespace))
@@ -446,13 +437,24 @@ class ResolverMixin(object):  # pylint: disable=too-few-public-methods
         for meth in new_class.methods.values():
             objects += list(meth.parameters.values())
 
-        # Validate the attributes of all qualifiers in the new class
+        # Validate the attributes of all qualifiers in the new class and that
+        # their value is True
         if qualifier_store:
+            if 'ASSOCIATION' in new_class.qualifiers and \
+                    new_class.qualifiers['ASSOCIATION']:
+                class_scope = 'ASSOCIATION'
+            elif 'INDICATION' in new_class.qualifiers and \
+                    new_class.qualifiers['INDICATION']:
+                class_scope = 'INDICATION'
+            else:
+                class_scope = 'CLASS'
             self._validate_qualifiers(new_class.qualifiers, qualifier_store,
-                                      new_class, 'CLASS')
+                                      new_class, class_scope)
             for prop in new_class.properties.values():
+                prop_scope = 'reference' if prop.type == 'reference' \
+                    else 'PROPERTY'
                 self._validate_qualifiers(prop.qualifiers, qualifier_store,
-                                          new_class, 'PROPERTY')
+                                          new_class, prop_scope)
             for meth in new_class.methods.values():
                 self._validate_qualifiers(meth.qualifiers, qualifier_store,
                                           new_class, 'METHOD')
